
const fs = require('fs');
const path = require('path');
const { execSync } = require('child_process');

const app_name = process.argv[2];

if (!app_name) {
  console.error("Usage: node setup-react-app.js <your-app-name>");
  process.exit(1);
}

const createReactAppCommand = `npx create-react-app ${app_name} --template typescript`;
execSync(createReactAppCommand, { stdio: 'inherit' });

process.chdir(app_name);

const installPackagesCommand = 'npm install zustand react-query';
execSync(installPackagesCommand, { stdio: 'inherit' });

const foldersToCreate = [
  'src/modules/todo/app/usecases',
  'src/modules/todo/data',
  'src/modules/todo/domain',
  'src/modules/todo/hooks',
  'src/modules/todo/presentation/components',
  'src/modules/todo/store',
  'src/common/store',
  'src/common/components',
];

for (const folderPath of foldersToCreate) {
  fs.mkdirSync(folderPath, { recursive: true });
}

const appFilePath = path.join(__dirname, 'src', 'App.tsx');
const newContent = `
import { QueryClient, QueryClientProvider } from "react-query";

const queryClient = new QueryClient({});

const App = () => {
  return (
    <QueryClientProvider client={queryClient}>

      <h1> React Clean MVVM Architecture</h1>

    </QueryClientProvider>
  );
};

export default App;
`;

fs.writeFileSync(appFilePath, newContent);
console.log('app.tsx updated.');

console.log('Your app is created with Zustand and React Query.');
